%define major      2
%define libname    %mklibname %{name} %{major}
%define libnamedev %mklibname %{name} -d

%bcond_with syswebrtc
%bcond_with python

Name:           pjproject
Version:        2.10
%define subrel 3
Release:        %mkrel 5
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries
License:        GPLv2+
URL:            http://www.pjsip.org
Source0:        https://github.com/pjsip/pjproject/archive/%{version}/pjproject-%{version}.tar.gz

# Tell the build system not to use most of the third_party directory
Patch1:         pjproject_no_third_party.patch
# Keep the .pc file clean
# see https://bugzilla.redhat.com/show_bug.cgi?id=728302#c66
Patch2:         pjproject_fixup_pc_file.patch
# Fix ARMv7 endianness
Patch4:         pjproject-armv7.patch
# Add aarch64 detection
Patch5:         pjproject-aarch64.patch
# Fix ppc64 detection
Patch6:         pjproject-ppc64.patch
# Don't use SSE2 if it is not available
Patch8:		pjproject-sse2.patch

Patch30:	pjproject-2.5.5-parallel.patch
Patch31:	pjproject-build-flags.patch

# From ring-daemon
Patch101:	0001-rfc6544.patch
Patch102:	0002-rfc2466.patch
Patch103:	0003-add-tcp-keep-alive.patch
Patch104:	0004-multiple_listeners.patch
Patch105:	0005-fix_ebusy_turn.patch
Patch106:	0006-ignore_ipv6_on_transport_check.patch
Patch107:	0007-pj_ice_sess.patch
Patch108:	0008-fix_ioqueue_ipv6_sendto.patch
Patch109:	0009-add-config-site.patch
# Disable for now, causes jamid to crash
#Patch110:	0007-upnp-srflx-nat-assisted-cand.patch
Patch111:	0011-fix-tcp-death-detection.patch
Patch112:	0012-fix-turn-shutdown-crash.patch
Patch113:	0013-Assign-unique-local-preferences-for-candidates-with-.patch
Patch114:	0014-Add-new-compile-time-setting-PJ_ICE_ST_USE_TURN_PERM.patch
Patch115:	0015-update-local-preference-for-peer-reflexive-candidate.patch


# 
# Security Patches
# P200 -> ...
# 
Patch200:	CVE-2021-21375.patch
Patch201:	pjproject-CVE-2020-15260.patch
# CVE-2021-32686
Patch202:	0001-Merge-pull-request-from-GHSA-cv8x-p47p-99wr.patch
BuildRequires:  gsm-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(libsrtp2)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(portaudio-2.0)
%if %{with python}
BuildRequires:  pkgconfig(python3)
%endif
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(speexdsp)

%description
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA


%package -n     %{libname}
Summary:        Libraries for building embedded/non-embedded VoIP applications
Group:          System/Libraries
%if ! %{with python}
Obsoletes:      python2-pjsua < %{version}-%{release}
Obsoletes:      python3-pjsua < %{version}-%{release}
%endif

%description -n %{libname}
This package provides the Open Source, comprehensive, high performance,
small footprint multimedia communication libraries written in C
language for building embedded/non-embedded VoIP applications.
It contains:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library
- PJSUA2 - Object Oriented abstractions layer for PJSUA

This package contains the shared library part of ccrtp.


%package -n     %{libnamedev}
Summary:        Development files to use pjproject
Group:          Development/Other
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}

%description -n %{libnamedev}
Header information for:
- PJSIP - Open Source SIP Stack
- PJMEDIA - Open Source Media Stack
- PJNATH - Open Source NAT Traversal Helper Library
- PJLIB-UTIL - Auxiliary Library
- PJLIB - Ultra Portable Base Framework Library


%package -n     pjsua
Summary:        command line SIP user agent
Group:          System/Libraries

%description -n pjsua
pjsua is an open source command line SIP user agent (softphone)
that is used as the reference implementation for PJSIP, PJNATH, and PJMEDIA.
Despite its simple command line appearance, it does pack many features!


%package -n     python3-pjsua
Summary:        PJSUA Python Module
Group:          Development/Python
Obsoletes:      python-pjsua < 2.5.5-5
Provides:       python-pjsua = %{version}-%{release}

%description -n python3-pjsua
The PJSUA for Python Module is an object oriented Python
wrapper/abstraction/modules for PJSUA API.

%prep
%setup -q
%autopatch -p1

# make sure we don't bundle these third-party libraries
# (They're excluded through ./configure, but this is an
# additional safety net)
rm -rf third_party/BaseClasses
rm -rf third_party/bdsound
rm -rf third_party/bin
rm -rf third_party/g7221
rm -rf third_party/gsm
rm -rf third_party/milenage
rm -rf third_party/mp3
rm -rf third_party/portaudio
rm -rf third_party/resample
rm -rf third_party/speex
rm -rf third_party/srtp
rm -rf third_party/ilbc
%if %{with syswebrtc}
rm -rf third_party/webrtc
%endif
rm -rf third_party/build/baseclasses
rm -rf third_party/build/g7221
rm -rf third_party/build/gsm
rm -rf third_party/build/milenage
rm -rf third_party/build/portaudio/src
rm -rf third_party/build/resample
rm -rf third_party/build/samplerate
rm -rf third_party/build/speex
rm -rf third_party/build/srtp
rm -rf third_party/build/ilbc
%if %{with syswebrtc}
rm -rf third_party/build/webrtc
%endif

%build
# Regenerate aconfigure for Patch8
autoconf aconfigure.ac > aconfigure

# We're building without audio or video support, as Asterisk isn't using
# that functionality, and it made it easier to ensure that we don't
# bundle any unnecessary libraries.  Please contact me if your project
# needs this support, and I'll re-enable it
export CFLAGS="-DPJ_HAS_IPV6=1 -DNDEBUG ${ARCHFLAGS} %{optflags}"

%configure \
	--enable-shared        \
	--with-external-gsm    \
	--with-external-pa     \
	--with-external-speex  \
	--with-external-srtp   \
%if %{with syswebrtc}
	--with-external-webrtc \
%endif
	--disable-opencore-amr \
	--disable-resample     \
	--disable-sound        \
	--disable-video        \
	--disable-v4l2         \
	--disable-ilbc-codec   \
	--disable-libyuv       \
	--disable-g7221-codec

%make_build dep
%make_build

%if %{with python}
pushd pjsip-apps/src/python
    %py3_build
popd
%endif

%install
%make_install

%if %{with python}
pushd pjsip-apps/src/python
    %py3_install
popd
%endif

install -p -D -m 0755 pjsip-apps/bin/pjsua-* %{buildroot}%{_bindir}/pjsua

# Remove the static libraries, as they aren't wanted
find %{buildroot} -type f -name "*.a" -delete


%files -n %{libname}
%doc README.txt README-RTEMS INSTALL.txt
%license COPYING
%{_libdir}/lib*.so.%{major}{,.*}

%files -n %{libnamedev}
%{_libdir}/lib*.so
%{_includedir}/pj++/
%{_includedir}/pj/
%{_includedir}/pjlib-util/
%{_includedir}/pjmedia-audiodev/
%{_includedir}/pjmedia-codec/
%{_includedir}/pjmedia-videodev/
%{_includedir}/pjmedia/
%{_includedir}/pjnath/
%{_includedir}/pjsip-simple/
%{_includedir}/pjsip-ua/
%{_includedir}/pjsip/
%{_includedir}/pjsua-lib/
%{_includedir}/pjsua2/
%{_includedir}/*.h
%{_includedir}/*.hpp
%{_libdir}/pkgconfig/libpjproject.pc

%if %{with python}
%files -n python3-pjsua
%doc pjsip-apps/src/python/samples
%{python3_sitearch}/_pjsua.so
%{python3_sitearch}/pjsua-*.egg-info
%{python3_sitearch}/pjsua.py*
%endif

%files -n pjsua
%{_bindir}/pjsua


%changelog
* Sat Dec 11 2021 neoclust <neoclust> 2.10-5.3.mga8
+ Revision: 1761392
- Add P202: Fixes CVE-2021-32686 (mga#29317)
+ luigiwalser <luigiwalser>
- rediff upstream patch to fix CVE-2020-15260
+ ns80 <ns80>
- add upstream patch for CVE-2021-21375 (mga#28998)

* Fri Dec 25 2020 wally <wally> 2.10-5.mga8
+ Revision: 1663705
- update patches from jami-daemon

* Sun Oct 25 2020 wally <wally> 2.10-4.mga8
+ Revision: 1639355
- rebuild with new libsrtp2

* Sat May 09 2020 wally <wally> 2.10-3.mga8
+ Revision: 1581929
- move python obsoletes to better place

* Thu May 07 2020 wally <wally> 2.10-2.mga8
+ Revision: 1581556
- obsolete python pkg if it's not built

* Sat May 02 2020 wally <wally> 2.10-1.mga8
+ Revision: 1577772
- new version 2.10
- disable python support for now
- update patches from ring-daemon

* Fri Feb 14 2020 umeabot <umeabot> 2.7.2-2.mga8
+ Revision: 1522151
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Jan 21 2019 wally <wally> 2.7.2-1.mga7
+ Revision: 1358708
- new version 2.7.2 to fix CVE-2017-16872, CVE-2017-16875, CVE-2018-1000098, CVE-2018-1000099 (mga#22894)
- update gnutls and rfc6062 patches from ring-daemon

* Thu Oct 04 2018 umeabot <umeabot> 2.6-2.mga7
+ Revision: 1317378
- Mageia 7 Mass Rebuild

* Sun Jan 07 2018 wally <wally> 2.6-1.mga7
+ Revision: 1191341
- new version 2.6
- sync patches with Fedora and ring-daemon project
- add rfc6062 patch from ring-daemon project

* Sat Sep 16 2017 daviddavid <daviddavid> 2.5.5-7.mga7
+ Revision: 1154729
- rebuild for new gcc7

* Sat Aug 12 2017 daviddavid <daviddavid> 2.5.5-6.mga7
+ Revision: 1139890
- fix version of obsoleted python-pjsua

* Sat Aug 12 2017 daviddavid <daviddavid> 2.5.5-5.mga7
+ Revision: 1139884
- add and rediff upstream patch to fix CVE-2017-9359 and CVE-2017-9372 (mga#21505)
- rename python-pjsua to python2-pjsua

* Thu Jun 15 2017 pterjan <pterjan> 2.5.5-4.mga6
+ Revision: 1107738
- Fix a parallel build problem

* Mon Jan 02 2017 neoclust <neoclust> 2.5.5-3.mga6
+ Revision: 1079590
- Add pj_ice_strans_get_ice_sess function ( needed for ring-daemon)
- Add PJSIP_TRANSPORT_DTLS ( needed for ring-daemon)

* Sun Jan 01 2017 neoclust <neoclust> 2.5.5-1.mga6
+ Revision: 1079427
- New version 2.5.5

* Wed Apr 13 2016 daviddavid <daviddavid> 2.4.5-5.mga6
+ Revision: 1001039
- rebuild against libsrtp (srtp was removed)
- use new python macros
- include config_site.h file to improve performance from fedora
- add -DNDEBUG to CFLAGS at request of Asterisk developers from fedora

* Thu Mar 03 2016 umeabot <umeabot> 2.4.5-4.mga6
+ Revision: 983909
- Rebuild for openssl

* Tue Feb 16 2016 umeabot <umeabot> 2.4.5-3.mga6
+ Revision: 962102
- Mageia 6 Mass Rebuild

* Sun Nov 08 2015 daviddavid <daviddavid> 2.4.5-2.mga6
+ Revision: 899113
- remove nonexistent requires

* Sat Nov 07 2015 daviddavid <daviddavid> 2.4.5-1.mga6
+ Revision: 898483
- new version: 2.4.5
- create sub-packages for pjsua and python bindings
- fix endian support for aarch64
- add missing BuildRequires on speexdsp to fix build

* Sun Feb 08 2015 alien <alien> 2.3-1.mga5
+ Revision: 814093
- imported package pjproject

